From 6dc2d7ba1890a492fc1d7a01b4c0f5e177f5cf0f Mon Sep 17 00:00:00 2001
From: Dirk Hohndel <dirk@hohndel.org>
Date: Sun, 22 Feb 2015 08:38:58 -0800
Subject: Start building packages for vivid

Signed-off-by: Dirk Hohndel <dirk@hohndel.org>
---
 packaging/ubuntu/make-package.sh | 12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

diff --git a/packaging/ubuntu/make-package.sh b/packaging/ubuntu/make-package.sh
index 6063e1b50..4942f85b7 100644
--- a/packaging/ubuntu/make-package.sh
+++ b/packaging/ubuntu/make-package.sh
@@ -77,16 +77,22 @@ dch -v $VERSION-$rev~trusty -D trusty -M -m "next daily build"
 mv ~/src/debian.changelog ~/src/debian.changelog.previous
 cp debian/changelog ~/src/debian.changelog
 
-debuild -S 
+debuild -S
 
-# and now for utopic (precise can't build Qt5 based packages)
+# and now for utopic
 prev=trusty
 rel=utopic
 sed -i "s/${prev}/${rel}/g" debian/changelog
 debuild -S
 
 # and now for precise
 prev=utopic
+rel=vivid
+sed -i "s/${prev}/${rel}/g" debian/changelog
+debuild -S
+
+# and now for precise (precise can't build Qt5 based packages)
+prev=vivid
 rel=precise
 sed -i "s/${prev}/${rel}/g" debian/changelog
 cp debian/12.04.control debian/control
@@ -77,16 +77,22 @@ dch -v $VERSION-$rev~trusty -D trusty -M -m "next daily build"
 debuild -S
 
-# and now for precise
+# and now for vivid
 prev=utopic
-- 
cgit v1.2.3-70-g09d2